@@ -17,21 +17,14 @@ log = logging.getLogger("FolderEditor")
 COLOR_NEW				= "#A0A0A0"
 # Regexp to generate folder id from filename
 RE_GEN_ID = re.compile("([a-zA-Z0-9\-\._]{1,64}).*")
-VALUES = [ "vid", "vpath", "vreadOnly", "vignorePerms", "vdevices",
+VALUES = [ "vid", "vlabel", "vpath", "vreadOnly", "vignorePerms", "vdevices",
 	"vversioning", "vkeepVersions", "vrescanIntervalS", "vmaxAge",
-	"vversionsPath", "vinotify", "vcleanoutDays", "vcommand"
+	"vversionsPath", "vinotify", "vcleanoutDays", "vcommand", "vorder",
+	"vminDiskFreePct"
 	]
 VERSIONING_TYPES = set(['simple', 'staggered', 'trashcan', 'external'])
 
 class FolderEditorDialog(EditorDialog):
-	MESSAGES = {
-		# Displayed when folder id is invalid
-		"vid" : _("The Folder ID must be a short, unique identifier"
-			" (64 characters or less) consisting of letters, numbers "
-			"and the the dot (.), dash (-) and underscode (_) "
-			"characters only"),
-	}
-	
 	def __init__(self, app, is_new, id=None, path=None):
 		EditorDialog.__init__(self, app,
 			"folder-edit.glade",
@@ -82,6 +75,8 @@ class FolderEditorDialog(EditorDialog):
 			return self.get_burried_value("versioning/params/command", self.values, "")
 		elif key == "versionsPath":
 			return self.get_burried_value("versioning/params/versionsPath", self.values, "")
+		elif key == "readOnly":
+			return self.get_burried_value("type", self.values, "") == "readonly"
 		elif key == "versioning":
 			return self.get_burried_value("versioning/type", self.values, "")
 		elif key == "inotify":
@@ -115,6 +110,8 @@ class FolderEditorDialog(EditorDialog):
 			# Create structure if needed
 			self.create_dicts(self.values, ("versioning", "params", "versionsPath"))
 			self.values["versioning"]["params"]["versionsPath"] = value
+		elif key == "readOnly":
+			self.values["type"] = "readonly" if value else "readwrite"
 		elif key == "inotify":
 			id = self.id
 			if id is None:
@@ -231,7 +228,7 @@ class FolderEditorDialog(EditorDialog):
 		# see that something happen even before daemon gets restarted
 		if self.is_new:
 			box = self.app.show_folder(
-				self.get_value("id"), self.get_value("path"), self.get_value("path"),
+				self.get_value("id"), self.get_value("label"), self.get_value("path"),
 				self.get_value("readOnly"), self.get_value("ignorePerms"),
 				self.get_value("rescanIntervalS"),
 				sorted(
