@@ -15,7 +15,7 @@ from win32com.shell import shell, shellcon
 log = logging.getLogger("windows.py")
 
 SM_SHUTTINGDOWN = 0x2000
-ST_INOTIFY_EXE = "syncthing-inotify-v0.7.exe"
+ST_INOTIFY_EXE = "syncthing-inotify-v0.8.2.exe"
 
 def fix_localized_system_error_messages():
 	"""
